/**package
 * {
 *   "name": "indexjs-test",
 *   "version": "1.2.3",
 *   "description": "Did you know npm could do this, even?",
 *   "main": "index.js"
 *
 *   but alas, 'twas not to be,
 *   for, when parse the comment we,
 *   json is not there to see
 *
 * }
 **/
console.log('just a broken single-file package')
